// src/plugins/nuxt3.ts
import { mkdir, writeFile } from "node:fs/promises";
import { resolve, dirname } from "node:path";
import { defineNuxtModule } from "@nuxt/kit";

// src/plugins/core/index.ts
import childProcess from "child_process";
var execCommand = (command) => {
  const { exec } = childProcess;
  return new Promise((resolve2, reject) => {
    exec(command, (error, stdout) => {
      if (error) {
        reject(error);
      } else {
        const output = stdout.toString()?.replace("\n", "");
        resolve2(output);
      }
    });
  });
};
var analyticOptions = async (options) => {
  const {
    name = process.env["npm_package_name"],
    version = process.env["npm_package_version"],
    command = void 0,
    ifShortSHA = false,
    ifGitSHA = false,
    ifMeta = true,
    ifLog = true,
    ifGlobal = true,
    ifExport = false,
    outputFile
  } = options;
  const finalCommand = command ?? (ifShortSHA ? "git rev-parse --short HEAD" : ifGitSHA ? "git rev-parse HEAD" : void 0);
  const printVersion = finalCommand ? await execCommand(finalCommand) : version;
  const printName = `${name?.replace(/((?!\w).)/g, "_")?.toLocaleUpperCase?.()}_VERSION`;
  const printInfo = `${printName}: ${printVersion}`;
  const fileList = (() => {
    switch (typeof outputFile) {
      case "function": {
        const res = outputFile(printVersion);
        return Array.isArray(res) ? res : [res];
      }
      case "boolean":
        return outputFile ? [{ path: ".well-known/version", content: printVersion }] : [];
      default:
        return [];
    }
  })();
  return {
    ifMeta,
    ifLog,
    ifGlobal,
    ifExport,
    fileList,
    printVersion,
    printName,
    printInfo
  };
};

// src/plugins/nuxt3.ts
var nuxt3Module = defineNuxtModule({
  meta: {
    name: "nuxt-version-mark"
  },
  // https://github.com/nuxt/bridge/blob/main/packages/bridge/src/module.ts
  async setup(options, nuxt) {
    const {
      fileList,
      ifMeta,
      ifLog,
      ifGlobal,
      printVersion,
      printName,
      printInfo
    } = await analyticOptions(options);
    nuxt.options.app.head.meta = nuxt.options.app.head.meta || [];
    nuxt.options.app.head.script = nuxt.options.app.head.script || [];
    nuxt.options.vite.define = nuxt.options.vite.define || {};
    if (ifMeta) {
      nuxt.options.app.head.meta.push({
        name: "application-name",
        content: printInfo
      });
    }
    if (ifLog) {
      nuxt.options.app.head.script.push({
        children: `console.log("${printInfo}")`
      });
    }
    if (ifGlobal) {
      nuxt.options.vite.define[`__${printName}__`] = JSON.stringify(printVersion);
      nuxt.options.app.head.script.push({
        children: `__${printName}__ = "${printVersion}"`
      });
    }
    if (fileList.length > 0) {
      nuxt.hook("nitro:build:public-assets", async ({ options: { output: { publicDir } } }) => {
        await Promise.all(fileList.map(async ({ path, content = "" }) => {
          const dir = dirname(path);
          const fullDir = resolve(publicDir, dir);
          const outputFilePath = resolve(publicDir, path);
          try {
            await mkdir(fullDir, { recursive: true });
            await writeFile(outputFilePath, content);
            console.info(`Generated version file in ${outputFilePath}`);
          } catch (error) {
            console.error(`Failed to generate file at ${outputFilePath}:`, error);
            throw error;
          }
        }));
      });
    }
  }
});
var nuxt3_default = nuxt3Module;
export {
  nuxt3_default as default
};
//# sourceMappingURL=index.js.map