// src/plugins/vite.ts
import { mkdir, writeFile } from "node:fs/promises";
import { resolve, dirname } from "node:path";

// src/plugins/core/index.ts
import childProcess from "child_process";
var execCommand = (command) => {
  const { exec } = childProcess;
  return new Promise((resolve2, reject) => {
    exec(command, (error, stdout) => {
      if (error) {
        reject(error);
      } else {
        const output = stdout.toString()?.replace("\n", "");
        resolve2(output);
      }
    });
  });
};
var analyticOptions = async (options) => {
  const {
    name = process.env["npm_package_name"],
    version = process.env["npm_package_version"],
    command = void 0,
    ifShortSHA = false,
    ifGitSHA = false,
    ifMeta = true,
    ifLog = true,
    ifGlobal = true,
    ifExport = false,
    outputFile
  } = options;
  const finalCommand = command ?? (ifShortSHA ? "git rev-parse --short HEAD" : ifGitSHA ? "git rev-parse HEAD" : void 0);
  const printVersion = finalCommand ? await execCommand(finalCommand) : version;
  const printName = `${name?.replace(/((?!\w).)/g, "_")?.toLocaleUpperCase?.()}_VERSION`;
  const printInfo = `${printName}: ${printVersion}`;
  const fileList = (() => {
    switch (typeof outputFile) {
      case "function": {
        const res = outputFile(printVersion);
        return Array.isArray(res) ? res : [res];
      }
      case "boolean":
        return outputFile ? [{ path: ".well-known/version", content: printVersion }] : [];
      default:
        return [];
    }
  })();
  return {
    ifMeta,
    ifLog,
    ifGlobal,
    ifExport,
    fileList,
    printVersion,
    printName,
    printInfo
  };
};

// src/plugins/vite.ts
var vitePluginVersionMark = (options = {}) => {
  let versionMarkConfig;
  const getVersionMarkConfig = async () => {
    if (!versionMarkConfig) versionMarkConfig = await analyticOptions(options);
    return versionMarkConfig;
  };
  let outDir;
  return {
    name: "vite-plugin-version-mark",
    async config() {
      const {
        ifGlobal,
        printName,
        printVersion
      } = await getVersionMarkConfig();
      if (ifGlobal) {
        const keyName = `__${printName}__`;
        return {
          define: {
            [keyName]: JSON.stringify(printVersion)
          }
        };
      }
    },
    async renderChunk(code, chunk) {
      if (chunk.isEntry) {
        const {
          ifExport,
          printName,
          printVersion
        } = await getVersionMarkConfig();
        let modifiedCode = code;
        if (ifExport) modifiedCode += `
export const ${printName} = '${printVersion}';`;
        return {
          code: modifiedCode,
          map: null
        };
      }
    },
    async transformIndexHtml() {
      const {
        ifLog,
        ifMeta,
        ifGlobal,
        printName,
        printVersion,
        printInfo
      } = await getVersionMarkConfig();
      const els = [];
      if (ifMeta) {
        els.push({
          tag: "meta",
          injectTo: "head-prepend",
          attrs: {
            name: "application-name",
            content: printInfo
          }
        });
      }
      if (ifLog) {
        els.push({
          tag: "script",
          injectTo: "head",
          children: `console.log("${printInfo}")`
        });
      }
      if (ifGlobal) {
        els.push({
          tag: "script",
          injectTo: "head",
          children: `__${printName}__ = "${printVersion}"`
        });
      }
      return els;
    },
    configResolved(config) {
      outDir = config.build.outDir;
    },
    async closeBundle() {
      const { fileList } = await getVersionMarkConfig();
      if (!fileList.length) return;
      await Promise.all(fileList.map(async ({ path, content = "" }) => {
        try {
          const dir = dirname(path);
          await mkdir(resolve(outDir, dir), { recursive: true });
          const outputFilePath = resolve(outDir, path);
          await writeFile(outputFilePath, content);
          this.info(`Generate version file in ${outputFilePath}`);
        } catch (error) {
          this.error(`Failed to generate version file at ${path}: ${error.message}`);
        }
      }));
    }
  };
};
export {
  vitePluginVersionMark
};
//# sourceMappingURL=index.js.map